@@ -31,8 +31,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 // first file to include
 #ifdef __GNUC__
+#if __GNUC__ > 5
+#pragma GCC diagnostic ignored "-Wpedantic"
+#else
 #pragma GCC diagnostic ignored "-pedantic"
 #endif
+#endif
 
 #include <postgres.h>
 
