@@ -1,8 +1,8 @@
 /*PGR-GNU*****************************************************************
 File: pgr_components_rt.h
 
-Copyright (c) 2015 Celia Virginia Vergara Castillo
-Mail: vicky_vergara@hotmail.com
+Copyright (c) 2017 Maoguang Wang
+Mail: xjtumg1007@gmail.com
 
 ------
 
@@ -36,8 +36,12 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 // for bool
 #ifdef __GNUC__
+#if __GNUC__ > 5
+#pragma GCC diagnostic ignored "-Wpedantic"
+#else
 #pragma GCC diagnostic ignored "-pedantic"
 #endif
+#endif
 
 #include <postgres.h>
 
