@@ -67,7 +67,7 @@ BEGIN
                 || astar_sql || ', '
                 || count_query  || ', '
                 || value_query
-                || ' (SELECT * FROM count_q) UNION (SELECT * FROM vc)';
+                || ' (SELECT * FROM count_q) UNION (SELECT * FROM vc) LIMIT 1';
 
             RETURN query SELECT results_eq(t_query, 'select true', t_query);
 
@@ -131,7 +131,7 @@ SELECT * from astarCompareDijkstra(5, 1, 78846, 1);
 SELECT * from astarCompareDijkstra(5, 1, 78846, 1.5);
 SELECT * from astarCompareDijkstra(5, 2, 78846, 1);
 SELECT * from astarCompareDijkstra(5, 2, 78846, 1.5);
-SELECT * from astarCompareDijkstra(5, 3, 78846, 1);
+SELECT * from astarCompareDijkstra(5, 0, 78846, 1);
 SELECT * from astarCompareDijkstra(5, 3, 78846, 1.5);
 SELECT * from astarCompareDijkstra(5, 4, 78846, 1);
 SELECT * from astarCompareDijkstra(5, 4, 78846, 1.5);
