@@ -32,5 +32,5 @@ CREATE OR REPLACE FUNCTION pgr_floydWarshall(edges_sql TEXT, directed BOOLEAN DE
   OUT start_vid BIGINT, OUT end_vid BIGINT, OUT agg_cost float)
   RETURNS SETOF RECORD AS
  '${MODULE_PATHNAME}', 'floydWarshall'
-    LANGUAGE c VOLATILE;
+    LANGUAGE c VOLATILE STRICT;
 
