@@ -32,5 +32,5 @@ CREATE OR REPLACE FUNCTION pgr_johnson(edges_sql TEXT, directed BOOLEAN DEFAULT
   OUT start_vid BIGINT, OUT end_vid BIGINT, OUT agg_cost float)
   RETURNS SETOF RECORD AS
  '${MODULE_PATHNAME}', 'johnson'
-    LANGUAGE c VOLATILE;
+    LANGUAGE c VOLATILE STRICT;
 
