@@ -44,6 +44,6 @@ CREATE OR REPLACE FUNCTION _pgr_bdAstar(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
     '${MODULE_PATHNAME}', 'bd_astar'
-LANGUAGE C VOLATILE;
+LANGUAGE C VOLATILE STRICT;
 
 
