@@ -41,5 +41,5 @@ CREATE OR REPLACE FUNCTION _pgr_bdDijkstra(
     OUT agg_cost FLOAT)
 RETURNS SETOF RECORD AS
 '${MODULE_PATHNAME}', 'bdDijkstra'
-LANGUAGE c VOLATILE;
+LANGUAGE c VOLATILE STRICT;
 
