@@ -42,4 +42,4 @@ CREATE OR REPLACE FUNCTION _pgr_dijkstra(
     OUT agg_cost float)
 RETURNS SETOF RECORD AS
 '${MODULE_PATHNAME}', 'many_to_many_dijkstra'
-LANGUAGE c VOLATILE;
+LANGUAGE c VOLATILE STRICT;
