@@ -54,27 +54,27 @@ fi
 if [[ -z  $1 ]]; then
     echo "Mayor missing";
     echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch DEBUG RC";
+    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
     exit 1;
 fi
 if [[ -z  $2 ]]; then
     echo "Minor missing";
     echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch DEBUG RC";
+    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
     exit 1;
 fi
 
 if [[ -z  $3 ]]; then
     echo "Micro missing";
     echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch DEBUG RC";
+    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
     exit 1;
 fi
 
 if [[ -z  $4 ]]; then
     echo "Last Micro missing";
     echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch DEBUG RC";
+    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
     exit 1;
 fi
 
@@ -82,7 +82,7 @@ fi
 if [[ -z  $5 ]]; then
     echo "branch missing";
     echo "Usage"
-    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch DEBUG RC";
+    echo "tools/release-scripts/release-check.sh Mayor Minor Micro Last branch RC DEBUG";
     exit 1;
 fi
 
@@ -109,11 +109,11 @@ echo
 
 GIT_BRANCH="$(git rev-parse --abbrev-ref HEAD)"
 
-if [[ "${GIT_BRANCH}" == "${BRANCH}" ]]; then
-    echo "- [x] Already in branch $BRANCH"
+if [[ "$GIT_BRANCH" == "$BRANCH" ]]; then
+    echo "- [x] Already in branch $BRANCH";
     echo
 else
-    error_msg "Current Branch is not: $BRANCH,  found $GIT_BRANCH"
+    error_msg "Current Branch is not: $BRANCH"
     exit 1
 fi
 
@@ -264,16 +264,9 @@ if [[ -n $DEBUG ]]; then
     echo "\`\`\`"
 fi
 
-if [[ "$BRANCH" != "master" &&  "$BRANCH" != "release/$MAYOR.$MINOR" ]]; then
-    if [[ $(cat VERSION | grep "release/$MAYOR.$MINOR") != *"release/$MAYOR.$MINOR" ]]; then
-        error_msg "VERSION should have release/$MAYOR.$MINOR"
-        exit 1
-    fi
-else
-    if [[ $(cat VERSION | grep "master") != *"master" ]]; then
-        error_msg "VERSION should have master"
-        exit 1
-    fi
+if [[ $(cat VERSION | grep "release/$MAYOR.$MINOR") != *"release/$MAYOR.$MINOR" ]]; then
+    error_msg "VERSION should have release/$MAYOR.$MINOR"
+    exit 1
 fi
 echo "  -[x] VERSION file branch: OK"
 
@@ -282,7 +275,9 @@ echo
 echo "### Checking signature files exist"
 echo
 #---------------------------------------------------------------------
+test_file 2.6.1
 test_file 2.6.0
+test_file 2.5.4
 test_file 2.5.3
 test_file 2.5.2
 test_file 2.5.1
@@ -310,22 +305,14 @@ echo
 #---------------------------------------------------------------------
 if [[ -n $DEBUG ]]; then
     echo "\`\`\`"
-    echo "bash tools/release-scripts/compile-release.sh 5   $MAYOR.$MINOR $MICRO"
-    echo "bash tools/release-scripts/compile-release.sh 4.9 $MAYOR.$MINOR $MICRO"
-    echo "bash tools/release-scripts/compile-release.sh 4.6 $MAYOR.$MINOR $MICRO"
+    echo "bash tools/release-scripts/compile-release.sh 8   $MAYOR.$MINOR $MICRO"
     echo "bash tools/release-scripts/compile-release.sh 4.8 $MAYOR.$MINOR $MICRO"
     echo "\`\`\`"
 fi
 
 
-if [[ "$BRANCH" == "develop" || $BRANCH == "master" || $BRANCH == "release/$MAYOR.$MINOR" ]]; then
-    if [[ -z  "$DEBUG" ]]; then
-        bash tools/release-scripts/compile-release.sh 4.9 $MAYOR.$MINOR $MICRO
-        bash tools/release-scripts/compile-release.sh 4.6 $MAYOR.$MINOR $MICRO
-        bash tools/release-scripts/compile-release.sh 5 $MAYOR.$MINOR $MICRO
-    fi
-fi
-bash tools/release-scripts/compile-release.sh 4.8 $MAYOR.$MINOR $MICRO
+bash tools/release-scripts/compile-release.sh 8 $MAYOR.$MINOR $MICRO
+bash tools/release-scripts/compile-release.sh 4.8   $MAYOR.$MINOR $MICRO
 
 echo - [x] completed local builds
 
@@ -333,11 +320,27 @@ echo - [x] completed local builds
 echo "### checking the signature files dont change"
 #---------------------------------------------------------------------
 
-sh tools/release-scripts/get_signatures.sh $MAYOR.$MINOR.$MICRO ___sig_generate___ sql/sigs >> build/tmp_sigs.txt
-
-if [[ -z  "$DEBUG" ]]; then
-    git_no_change
-fi
+sh tools/release-scripts/get_signatures.sh 2.6.1 ___sig_generate___ sql/sigs >> build/tmp_sigs.txt
+test_file 2.6.0
+test_file 2.5.4
+test_file 2.5.3
+test_file 2.5.2
+test_file 2.5.1
+test_file 2.5.0
+test_file 2.4.2
+test_file 2.4.1
+test_file 2.4.0
+test_file 2.3.2
+test_file 2.3.1
+test_file 2.3.0
+test_file 2.2.4
+test_file 2.2.3
+test_file 2.2.2
+test_file 2.2.1
+test_file 2.2.0
+test_file 2.1.0
+test_file 2.0.1
+test_file 2.0.0
 
 echo
 echo - [x] completed check: OK
@@ -370,10 +373,8 @@ if [[ $? != 0 ]]; then
     exit 1
 fi
 
-if [[ -z  "$DEBUG" ]]; then
-    git_no_change
-elif [[ $(git status | grep 'Changes not staged for commit:') ]]; then
-    echo "DEBUG WARNING: at least one file changed"
+if [[ $(git status | grep 'Changes not staged for commit:') ]]; then
+    echo "FATAL: at least one result file changed"
     git status
     exit 1
 fi
