@@ -44,27 +44,20 @@ if test -z "$DIRECTORY"; then
     echo --------------------
     echo ------   *.c  ------
     echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --extensions=c src/*/src/*.c
+    python code_linter/styleguide/cpplint/cpplint.py --extensions=c --filter=-readability/casting src/*/*.c
     echo --------------------
     echo ------ *.cpp  ------
     echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/*/src/*.cpp
+    python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/*/*.cpp
     echo --------------------
     echo ------ HEADERS  ------
     echo --------------------
     python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h --filter=-runtime/references \
-        src/*/src/*.h \
-        src/*/src/*.hpp \
         include/*/*.h* \
         include/*/*/*.h*
 
 else
     if [ "$DIRECTORY" = "h" ]; then
-    echo --------------------
-    echo ------ OUT OF PLACE HEADERS  ------
-    echo --------------------
-    python code_linter/styleguide/cpplint/cpplint.py --extensions=hpp,h --headers=hpp,h --filter=-runtime/references \
-        src/*/src/*.h* 
 
     echo --------------------
     echo ------ IN PLACE HEADERS  ------
@@ -77,11 +70,11 @@ else
         echo --------------------
         echo ------   *.c  ------
         echo --------------------
-        python code_linter/styleguide/cpplint/cpplint.py --extensions=c --filter=-readability/casting src/$DIRECTORY/src/*.c
+        python code_linter/styleguide/cpplint/cpplint.py --extensions=c --filter=-readability/casting src/$DIRECTORY/*.c
         echo --------------------
         echo ------ *.cpp  ------
         echo --------------------
-        python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/$DIRECTORY/src/*.cpp
+        python code_linter/styleguide/cpplint/cpplint.py --filter=-runtime/references src/$DIRECTORY/*.cpp
         echo --------------------
         echo ------   C HEADER  ------
         echo --------------------
