@@ -9,14 +9,23 @@
 set -e
 
 PGUSER=$1
-RELEASE_TYPE="b$2"
+PGPORT=$2
+RELEASE_TYPE="b$3"
 echo "RELEASE_TYPE" $RELEASE_TYPE
-
+if [ "b$PGPORT" = "b" ]
+then
+    PGPORT=""
+else
+    PGPORT=" -p $PGPORT"
+fi
 PGDATABASE="___pgr___test___"
+echo $PGPORT
+
+
 
 # Define alias function for psql command
 run_psql () {
-    PGOPTIONS='--client-min-messages=warning' psql -U $PGUSER  -d $PGDATABASE -X -q -v ON_ERROR_STOP=1 --pset pager=off "$@"
+    PGOPTIONS='--client-min-messages=warning' psql $PGPORT -U $PGUSER  -d $PGDATABASE -X -q -v ON_ERROR_STOP=1 --pset pager=off "$@"
     if [ "$?" -ne 0 ]
     then
         echo "Test query failed: $@"
@@ -34,16 +43,14 @@ run_psql -f setup_db.sql
 
 if [ $RELEASE_TYPE = "bDebug" ]
 then
-    pg_prove ../../src/internalQueryTests/test/pgtap/* -d $PGDATABASE  -U $PGUSER
-    pg_prove ../../src/tsp/test/performance/* -d $PGDATABASE  -U $PGUSER
+    pg_prove ../../src/internalQueryTests/test/pgtap/* $PGPORT -d $PGDATABASE  -U $PGUSER
+    pg_prove ../../src/tsp/test/performance/* $PGPORT -d $PGDATABASE  -U $PGUSER
     echo "MADE TEST **********************"
 fi
 
-#pg_prove ../../src/dijkstraTRSP/test/pgtap/* -d $PGDATABASE -U $PGUSER
 
-pg_prove ../../src/lineGraph/test/pgtap/* -d $PGDATABASE -U $PGUSER
+pg_prove $PGPORT -d $PGDATABASE  -U $PGUSER ../../pgtap/*/*
 
-pg_prove -d $PGDATABASE  -U $PGUSER ../../pgtap/*/*
 
 if [ "$?" -ne 0 ]
 then
